aboutsummaryrefslogtreecommitdiff
path: root/azalea-entity/src/plugin/relative_updates.rs
diff options
context:
space:
mode:
authormat <git@matdoes.dev>2023-09-14 16:48:21 -0500
committermat <git@matdoes.dev>2023-09-14 16:48:21 -0500
commit83784d5a350168edaade4620122c2c6d46bc81a2 (patch)
treee126bb4849414fff78d24c65f93376f07f44e634 /azalea-entity/src/plugin/relative_updates.rs
parentdea4a656a574318fc011e0545046b0d78b0e816e (diff)
downloadazalea-drasl-83784d5a350168edaade4620122c2c6d46bc81a2.tar.xz
rename Local to LocalEntity
Diffstat (limited to 'azalea-entity/src/plugin/relative_updates.rs')
-rw-r--r--azalea-entity/src/plugin/relative_updates.rs15
1 files changed, 9 insertions, 6 deletions
diff --git a/azalea-entity/src/plugin/relative_updates.rs b/azalea-entity/src/plugin/relative_updates.rs
index 21b57cff..45b85203 100644
--- a/azalea-entity/src/plugin/relative_updates.rs
+++ b/azalea-entity/src/plugin/relative_updates.rs
@@ -28,7 +28,7 @@ use derive_more::{Deref, DerefMut};
use log::warn;
use parking_lot::RwLock;
-use crate::Local;
+use crate::LocalEntity;
/// An [`EntityCommand`] that applies a "relative update" to an entity, which
/// means this update won't be run multiple times by different clients in the
@@ -69,7 +69,7 @@ impl EntityCommand for RelativeEntityUpdate {
};
let entity_id = *entity_mut.get::<MinecraftEntityId>().unwrap();
- if entity_mut.contains::<Local>() {
+ if entity_mut.contains::<LocalEntity>() {
// a client tried to update another client, which isn't allowed
return;
}
@@ -99,12 +99,15 @@ impl EntityCommand for RelativeEntityUpdate {
}
}
/// The [`UpdatesReceived`] component should never be on [`Local`] entities.
/// This warns if an entity has both components.
pub fn debug_detect_updates_received_on_local_entities(
- query: Query<Entity, (With<Local>, With<UpdatesReceived>)>,
+ query: Query<Entity, (With<LocalEntity>, With<UpdatesReceived>)>,
) {
for entity in &query {
- warn!("Entity {:?} has both Local and UpdatesReceived", entity);
+ warn!(
+ "Entity {:?} has both LocalEntity and UpdatesReceived",
+ entity
+ );
}
}
@@ -99,12 +99,15 @@ impl EntityCommand for RelativeEntityUpdate {
}
}
-/// The [`UpdatesReceived`] component should never be on [`Local`] entities.
-/// This warns if an entity has both components.
+/// The [`UpdatesReceived`] component should never be on [`LocalEntity`]
+/// entities. This warns if an entity has both components.
pub fn debug_detect_updates_received_on_local_entities(